# mydstools

`mydstools`: **Data Science Toolbox**

Follow the project on:

* [Github](https://github.com/antobzzll/mydstools)
* [PyPI](https://pypi.org/project/mydstools/)

## Installation

```bash
$ pip install mydstools
```

## Usage

For a complete usage guide, please refer to the [example notebook](docs/example.ipynb).

## Contributing

Interested in contributing? Check out the [contributing guidelines](CONTRIBUTING.md). Please note that this project is released with a [Code of Conduct](CONDUCT.md). By contributing to this project, you agree to abide by its terms.

## License

`mydstools` was created by Antonio Buzzelli. It is licensed under the terms of the [MIT license](LICENSE).

## Credits

`mydstools` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
